#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class NumericArrayBlock < Block
		# This class represents a numeric array block.
		
		attr_reader(:filename, :variable_name, :data, :tape_representation, :tape_header)
		attr_writer(:tape_representation, :tape_header)

		def initialize(filename, data, variable_name)
			@tape_representation = nil
			@tape_header = nil

			@filename = filename
			@data = data
			@variable_name = variable_name[0].chr
		end

		def filename=(f)
			@filename = f
			@tape_header.filename = filename unless (@tape_representation.nil?)
		end
		
		def variable_name=(variable_name)
			@variable_name = variable_name[0].chr
			@tape_header.start_address = line unless (@tape_representation.nil?)
		end

		def block_length
			@data.size
		end

		def to_a
			@data
		end

		def write_tap_block(io)
			@tape_representation = self.canonical_tape_representation if (@tape_representation.nil?)
			@tape_representation.each { |block|
				block.write_tap_block(io)
			}
		end

		def write_tzx_block(io)
			@tape_representation = self.canonical_tape_representation if (@tape_representation.nil?)
			@tape_representation.each { |block|
				block.write_tzx_block(io)
			}
		end

		def canonical_tape_representation
			[NumericArrayHeaderTapeBlock.new(self), DataTapeBlock(self)]
		end

		def NumericArrayBlock.from_tape(subblocks)
			# find the header and datablock
			header = nil
			datablock = nil
			subblocks.each { |block|
				if block.is_a? NumericArrayHeaderTapeBlock
					header = block
				end
				if block.is_a? DataTapeBlock
					datablock = block
					break
				end unless header.nil?
			}
			raise "NumericArrayHeaderTapeBlock missing from tape block list" if header.nil?
			raise "DataTapeBlock missing from tape block list" if datablock.nil?

			block = NumericArrayBlock.new(header.filename, datablock.data, header.variable_name)
			block.tape_representation = subblocks
			header.datasource = block
			datablock.datasource = block
			block
		end

		def to_s
			"Numeric array: \"#{self.filename}\" DATA #{self.variable_name}() (#{self.data.length} bytes)"
		end

	end # NumericArrayBlock
end # ZXMedia