#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class CharacterArrayHeaderTapeBlock < ArrayHeaderTapeBlock

		def header_type_id
			2
		end
		
		def to_s
			"Header for character array \'#{self.filename}\' DATA #{self.variable_name}$"
		end

		def header_tape_extra_data
			[@param1, @variable_name.upcase[0] + 128] + Common.word_little_endian(@param2)
		end

		def CharacterArrayHeaderTapeBlock.can_promote?(block)
			if block.is_a? HeaderTapeBlock
				block.header_type_id == 2 && block.extra_data.size == 4
			else
				false
			end
		end

		def CharacterArrayHeaderTapeBlock.promote(block)
			data = block.extra_data
			param1 = data[0]
			variable_name = (data[1] - 128).chr
			param2 = data[2] | (data[3] << 8)
			ahtb = CharacterArrayHeaderTapeBlock.new(block.filename, block.block_length, variable_name, param1, param2)
			block.datasource = ahtb
			ahtb.header_tape_block = block
			ahtb
		end

	end # CharacterArrayHeaderTapeBlock
end # ZXMedia