#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class DataTapeBlock < Block
		# This class represents a data block on a tape (i.e. the bit after a header that actually gets loaded)
		
		attr_reader(:datasource, :rom_tape_block)
		attr_writer(:datasource, :rom_tape_block)

		def initialize(data)
			# allow passing either a data array, or an external object to use as a datasource
			if data.is_a? Array
				@data = data
				@datasource = nil
			else
				@datasource = data
				@data = []
			end
			self.rom_tape_block = ROMTapeBlock.new(self, 255)
		end
		
		def to_s
			"Data block (#{self.data.size} bytes)"
		end

		def data
			if @datasource.nil?
				@data
			else
				@datasource.data
			end
		end

		def data=(x)
			raise "Cannot assign data to this block directly" unless @datasource.nil?
			@data = x
		end

		def rom_tape_data
			self.data
		end

		def write_tap_block(io)
			self.rom_tape_block.write_tap_block(io)
		end
		
		def write_tzx_block(io)
			self.rom_tape_block.write_tzx_block(io)
		end

		def DataTapeBlock.can_promote?(block)
			if block.is_a? ROMTapeBlock
				block.block_identifier == 255
			else
				false
			end
		end

		def DataTapeBlock.promote(block)
			dtb = DataTapeBlock.new(block.data)
			block.datasource = dtb
			dtb.rom_tape_block = block
			dtb
		end

	end # DataTapeBlock
end # ZXMedia