#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class DirectRecordedTapeBlock < Block
		# This tape-specific block contains raw one-bit tape samples made at a constant rate

		attr_reader(:t_states_per_sample, :trailing_pause_length, :trailing_bits, :data)
		attr_writer(:t_states_per_sample, :trailing_pause_length, :trailing_bits)

		def initialize(data, t_states_per_sample, trailing_pause_length = 1000, trailing_bits = 8)
			@data = data
			@t_states_per_sample = t_states_per_sample
			@trailing_pause_length = trailing_pause_length
			@trailing_bits = trailing_bits
		end
		
		def write_tzx_block(io)
			io.putc 0x15
			io << Common.word_little_endian(@t_states_per_sample).pack('c*')
			io << Common.word_little_endian(@trailing_pause_length).pack('c*')
			io.putc @trailing_bits
			io << Common.triplet_little_endian(@data.size).pack('c*')
			io << @data.pack('c*')
		end
		
		def sample_frequency
			3500000 / @t_states_per_sample
		end
		
		def sample_count
			(8 * (@data.size - 1)) + @trailing_bits
		end
		
		def to_s
			"Direct tape recording (#{sample_count} samples @ #{sample_frequency}Hz)"
		end
		
	end # DirectRecordedTapeBlock
end # ZXMedia