#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class MessageTapeBlock < Block
		# This tape-specific block contains text to be displayed to the user.

		attr_reader(:text, :show_time)
		attr_writer(:text, :show_time)

		def initialize(text, show_time)
			@text = text
			@show_time = show_time
		end
		
		def write_tzx_block(io)
			io.putc 0x31
			io.putc @show_time
			io.putc @text.length
			io.write @text
		end

		def write_tap_block(io)
			# this block can sensibly be dropped without warning when writing to TAP
		end

		def preserves_tape_loading_continuity?
			true
		end

		def to_s
			"Message: \"#{@text}\" (display for #{@show_time} seconds)"
		end

	end # MessageTapeBlock
end # ZXMedia