#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class StandardSpeedTapeBlock < Block
		# This class defines a raw block of data from a tape, stored at standard ROM speed.
		# It makes no inferences as to the meaning of that data.
		# When importing, these usually won't hang around long before being translated into a RomTapeBlock.

		# If datasource is defined, we get the data from there rather than the internal @data array.
		# NB: This means that setting a datasource, hacking around with the data, and then setting
		# datasource back to nil will cause the data to revert to what it was originally. So do try
		# not to do that...

		attr_reader(:trailing_pause_length, :datasource)
		attr_writer(:trailing_pause_length, :datasource)

		def initialize(data, trailing_pause_length = 1000)
			# allow passing either a data array, or an external object to use as a datasource
			if data.is_a? Array
				@data = data
				@datasource = nil
			else
				@datasource = data
				@data = []
			end
			@trailing_pause_length = trailing_pause_length
		end
		
		def data
			if @datasource.nil?
				@data
			else
				@datasource.standard_speed_tape_data
			end
		end

		def data=(x)
			raise "Cannot assign data to this block directly" unless @datasource.nil?
			@data = x
		end
		
		def write_tap_block(io)
			data = self.data
			io << Common.word_little_endian(data.size).pack('c*')
			io << data.pack('c*')
		end
		
		def write_tzx_block(io)
			data = self.data
			io.putc 0x10
			io << Common.word_little_endian(@trailing_pause_length).pack('c*')
			io << Common.word_little_endian(data.size).pack('c*')
			io << data.pack('c*')
		end

		def to_s
			"Standard speed data (#{self.data.size} bytes)"
		end
		
		def StandardSpeedTapeBlock.promotion_targets
			[ROMTapeBlock]
		end
		
	end # StandardSpeedTapeBlock
end # ZXMedia