#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class TurboTapeBlock < Block
		# This class defines a raw block of data from a tape, stored with non-standard timings.

		attr_reader(:pilot_pulse_length, :sync_first_pulse_length, :sync_second_pulse_length, :zero_bit_pulse_length, :one_bit_pulse_length, :pilot_tone_length, :trailing_bits, :trailing_pause_length, :data)
		attr_writer(:pilot_pulse_length, :sync_first_pulse_length, :sync_second_pulse_length, :zero_bit_pulse_length, :one_bit_pulse_length, :pilot_tone_length, :trailing_bits, :trailing_pause_length)

		def initialize(data, pilot_pulse_length = 2168, sync_first_pulse_length = 667, sync_second_pulse_length = 735, zero_bit_pulse_length = 855, one_bit_pulse_length = 1710, pilot_tone_length = 8064, trailing_bits = 8, trailing_pause_length = 1000)
			@data = data
			@pilot_pulse_length = pilot_pulse_length
			@sync_first_pulse_length = sync_first_pulse_length
			@sync_second_pulse_length = sync_second_pulse_length
			@zero_bit_pulse_length = zero_bit_pulse_length
			@one_bit_pulse_length = one_bit_pulse_length
			@pilot_tone_length = pilot_tone_length
			@trailing_bits = trailing_bits
			@trailing_pause_length = trailing_pause_length
		end
		
		def write_tzx_block(io)
			io.putc 0x11
			io << Common.word_little_endian(@pilot_pulse_length).pack('c*')
			io << Common.word_little_endian(@sync_first_pulse_length).pack('c*')
			io << Common.word_little_endian(@sync_second_pulse_length).pack('c*')
			io << Common.word_little_endian(@zero_bit_pulse_length).pack('c*')
			io << Common.word_little_endian(@one_bit_pulse_length).pack('c*')
			io << Common.word_little_endian(@pilot_tone_length).pack('c*')
			io.putc @trailing_bits
			io << Common.word_little_endian(@trailing_pause_length).pack('c*')
			io << Common.triplet_little_endian(@data.size).pack('c*')
			io << @data.pack('c*')
		end

		def bit_count
			8 * (@data.size - 1) + @trailing_bits
		end
		
		def to_s
			"Turbo loading data (#{bit_count} bits)"
		end

	end # TurboTapeBlock
end # ZXMedia